/*
 * Copyright (C) 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.google.clearsilver.jsilver.exceptions;

import java.io.IOException;

/**
 * JSilver failed to access underlying IO stream. Wraps an IOException to make it a
 * RuntimeException.
 */
public class JSilverIOException extends JSilverException {

  public JSilverIOException(IOException cause) {
    super(cause.getMessage());
    initCause(cause);
  }

}
